@@ -45,8 +45,16 @@ async function getSecretJsonValue(arn) {
 
 // src/lambdas/webhook-handler.lambda.ts
 var sf = new AWS2.StepFunctions();
+function getHeader(event, header) {
+  for (const headerName of Object.keys(event.headers)) {
+    if (headerName.toLowerCase() === header.toLowerCase()) {
+      return event.headers[headerName];
+    }
+  }
+  return void 0;
+}
 function verifyBody(event, secret) {
-  const sig = Buffer.from(event.headers["x-hub-signature-256"] || "", "utf8");
+  const sig = Buffer.from(getHeader(event, "x-hub-signature-256") || "", "utf8");
   if (!event.body) {
     throw new Error("No body");
   }
@@ -81,21 +89,21 @@ exports.handler = async function(event) {
       body: "Bad signature"
     };
   }
-  if (event.headers["content-type"] !== "application/json") {
-    console.error(`This webhook only accepts JSON payloads, got ${event.headers["content-type"]}`);
+  if (getHeader(event, "content-type") !== "application/json") {
+    console.error(`This webhook only accepts JSON payloads, got ${getHeader(event, "content-type")}`);
     return {
       statusCode: 400,
       body: "Expecting JSON payload"
     };
   }
-  if (event.headers["x-github-event"] === "ping") {
+  if (getHeader(event, "x-github-event") === "ping") {
     return {
       statusCode: 200,
       body: "Pong"
     };
   }
-  if (event.headers["x-github-event"] !== "workflow_job") {
-    console.error(`This webhook only accepts workflow_job, got ${event.headers["x-github-event"]}`);
+  if (getHeader(event, "x-github-event") !== "workflow_job") {
+    console.error(`This webhook only accepts workflow_job, got ${getHeader(event, "x-github-event")}`);
     return {
       statusCode: 400,
       body: "Expecting workflow_job"
@@ -118,7 +126,7 @@ exports.handler = async function(event) {
   }
   let labels = {};
   payload.workflow_job.labels.forEach((l) => labels[l.toLowerCase()] = true);
-  let executionName = `${payload.repository.full_name.replace("/", "-")}-${event.headers["x-github-delivery"]}`.slice(0, 64);
+  let executionName = `${payload.repository.full_name.replace("/", "-")}-${getHeader(event, "x-github-delivery")}`.slice(0, 64);
   const execution = await sf.startExecution({
     stateMachineArn: process.env.STEP_FUNCTION_ARN,
     input: JSON.stringify({
